==> immersiveoverlays-1.4.2%2B1.19.2-fabric-sources.jar: cc/cassian/immersiveoverlays/mixin/MapAtlasAccessUtilsMixin.java <==
package cc.cassian.immersiveoverlays.mixin;


import cc.cassian.immersiveoverlays.config.ModConfig;
import cc.cassian.immersiveoverlays.overlay.OverlayHelpers;
import net.minecraft.class_1661;
import net.minecraft.class_1799;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Pseudo;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;
import pepjebs.mapatlases.MapAtlasesMod;
import pepjebs.mapatlases.utils.MapAtlasesAccessUtils;

@Pseudo
@Mixin(MapAtlasesAccessUtils.class)
public class MapAtlasAccessUtilsMixin {
    //? if >1.20 || forge {
    /*@Inject(method = "getAtlasFromInventory", at = @At(value = "RETURN"), remap = false, cancellable = true)
    private static void mixin(Inventory inventory, boolean onlyHotbar, CallbackInfoReturnable<ItemStack> cir) {
        if (ModConfig.get().compat_map_atlases) {
            if (cir.getReturnValue().equals(ItemStack.EMPTY)) {
                cir.setReturnValue(OverlayHelpers.checkInventoryForStack(inventory, MapAtlasesMod.MAP_ATLAS.get()));
            }
        }
    }
    *///?} else {
    @Inject(method = "getAtlasFromInventory", at = @At(value = "RETURN"), remap = false, cancellable = true)
    private static void mixin(class_1661 inventory, CallbackInfoReturnable<class_1799> cir) {
        if (cir.getReturnValue() == null) {
            cir.setReturnValue(OverlayHelpers.checkInventoryForStack(inventory, MapAtlasesMod.MAP_ATLAS));
        }
    }
    //?}
}

==> immersiveoverlays-1.4.5%2B1.20.6-fabric-sources.jar: cc/cassian/immersiveoverlays/mixin/MapAtlasAccessUtilsMixin.java <==
package cc.cassian.immersiveoverlays.mixin;


import cc.cassian.immersiveoverlays.config.ModConfig;
import cc.cassian.immersiveoverlays.overlay.OverlayHelpers;
import net.minecraft.class_1661;
import net.minecraft.class_1799;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Pseudo;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;
import pepjebs.mapatlases.MapAtlasesMod;
import pepjebs.mapatlases.utils.MapAtlasesAccessUtils;

@Pseudo
@Mixin(MapAtlasesAccessUtils.class)
public class MapAtlasAccessUtilsMixin {
    //? if >1.20 || forge {
    @Inject(method = "getAtlasFromInventory", at = @At(value = "RETURN"), remap = false, cancellable = true)
    private static void mixin(class_1661 inventory, boolean onlyHotbar, CallbackInfoReturnable<class_1799> cir) {
        if (ModConfig.get().compat_map_atlases) {
            if (cir.getReturnValue().equals(class_1799.field_8037)) {
                cir.setReturnValue(OverlayHelpers.checkInventoryForStack(inventory, MapAtlasesMod.MAP_ATLAS.get()));
            }
        }
    }
    //?} else {
    /*@Inject(method = "getAtlasFromInventory", at = @At(value = "RETURN"), remap = false, cancellable = true)
    private static void mixin(Inventory inventory, CallbackInfoReturnable<ItemStack> cir) {
        if (cir.getReturnValue() == null) {
            cir.setReturnValue(OverlayHelpers.checkInventoryForStack(inventory, MapAtlasesMod.MAP_ATLAS));
        }
    }
    *///?}
}
